function fmtfig(fs,ls,fn)
% formatfig(fs,ls)
%   fs: font size
%   ls: line size
%   fn: font name

% Copyright (C) M.Hirata, 2008
% Ver.1.0, 2008-05-02
% Ver.1.1, 2008-06-13 LineWidthの変更が無効になっていたので処理を追加

if nargin == 0
    fs = 14;
    ls = 1;
    fn = 'Times';
elseif nargin == 1
    ls = 1;
    fn = 'Times';
elseif nargin == 2
    fn = 'Times';
elseif nargin > 3
    error('Numbers of input argument is incorrect');
end

h = get(gcf,'children');
n = size(h);
for i=1:n
    t = get(h(i),'type');
    if strcmp(t,'axes')
        set(h(i),'fontsize',fs,'fontname',fn);
        set(get(h(i),'Xlabel'),'fontsize',fs,'fontname',fn);
        set(get(h(i),'Ylabel'),'fontsize',fs,'fontname',fn);
        set(get(h(i),'Title'),'fontsize',fs,'fontname',fn);
        ch = get(h(i),'children');
        nch = length(ch);
        for j=1:nch
            set(ch(j),'linewidth',ls);
        end
    end
end
% EOF of fmtfig.m
